authv1

package
v0.20.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2026 License: Unlicense Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_gx_auth_v1_session_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Auth

type Auth struct {

	// Types that are valid to be assigned to Auth:
	//
	//	*Auth_Otp
	//	*Auth_Nonce_
	//	*Auth_Token_
	Auth isAuth_Auth `protobuf_oneof:"auth"`
	// contains filtered or unexported fields
}

func (*Auth) Descriptor deprecated

func (*Auth) Descriptor() ([]byte, []int)

Deprecated: Use Auth.ProtoReflect.Descriptor instead.

func (*Auth) GetAuth

func (x *Auth) GetAuth() isAuth_Auth

func (*Auth) GetNonce added in v0.15.0

func (x *Auth) GetNonce() *Auth_Nonce

func (*Auth) GetOtp

func (x *Auth) GetOtp() *Auth_OTP

func (*Auth) GetToken

func (x *Auth) GetToken() *Auth_Token

func (*Auth) MarshalJSON

func (msg *Auth) MarshalJSON() ([]byte, error)

MarshalJSON implements json.Marshaler

func (*Auth) ProtoMessage

func (*Auth) ProtoMessage()

func (*Auth) ProtoReflect

func (x *Auth) ProtoReflect() protoreflect.Message

func (*Auth) Reset

func (x *Auth) Reset()

func (*Auth) String

func (x *Auth) String() string

func (*Auth) UnmarshalJSON

func (msg *Auth) UnmarshalJSON(b []byte) error

UnmarshalJSON implements json.Unmarshaler

type Auth_Nonce added in v0.15.0

type Auth_Nonce struct {
	Value     []byte `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
	ExpiresAt int64  `protobuf:"varint,2,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
	// contains filtered or unexported fields
}

func (*Auth_Nonce) Descriptor deprecated added in v0.15.0

func (*Auth_Nonce) Descriptor() ([]byte, []int)

Deprecated: Use Auth_Nonce.ProtoReflect.Descriptor instead.

func (*Auth_Nonce) GetExpiresAt added in v0.15.0

func (x *Auth_Nonce) GetExpiresAt() int64

func (*Auth_Nonce) GetValue added in v0.17.0

func (x *Auth_Nonce) GetValue() []byte

func (*Auth_Nonce) MarshalJSON added in v0.15.0

func (msg *Auth_Nonce) MarshalJSON() ([]byte, error)

MarshalJSON implements json.Marshaler

func (*Auth_Nonce) ProtoMessage added in v0.15.0

func (*Auth_Nonce) ProtoMessage()

func (*Auth_Nonce) ProtoReflect added in v0.15.0

func (x *Auth_Nonce) ProtoReflect() protoreflect.Message

func (*Auth_Nonce) Reset added in v0.15.0

func (x *Auth_Nonce) Reset()

func (*Auth_Nonce) String added in v0.15.0

func (x *Auth_Nonce) String() string

func (*Auth_Nonce) UnmarshalJSON added in v0.15.0

func (msg *Auth_Nonce) UnmarshalJSON(b []byte) error

UnmarshalJSON implements json.Unmarshaler

type Auth_Nonce_ added in v0.15.0

type Auth_Nonce_ struct {
	Nonce *Auth_Nonce `protobuf:"bytes,2,opt,name=nonce,proto3,oneof"`
}

type Auth_OTP

type Auth_OTP struct {
	Code      []byte `protobuf:"bytes,1,opt,name=code,proto3" json:"code,omitempty"`
	ExpiresAt int64  `protobuf:"varint,2,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
	Attempts  int32  `protobuf:"varint,3,opt,name=attempts,proto3" json:"attempts,omitempty"`
	// contains filtered or unexported fields
}

func (*Auth_OTP) Descriptor deprecated

func (*Auth_OTP) Descriptor() ([]byte, []int)

Deprecated: Use Auth_OTP.ProtoReflect.Descriptor instead.

func (*Auth_OTP) GetAttempts added in v0.17.0

func (x *Auth_OTP) GetAttempts() int32

func (*Auth_OTP) GetCode

func (x *Auth_OTP) GetCode() []byte

func (*Auth_OTP) GetExpiresAt

func (x *Auth_OTP) GetExpiresAt() int64

func (*Auth_OTP) MarshalJSON

func (msg *Auth_OTP) MarshalJSON() ([]byte, error)

MarshalJSON implements json.Marshaler

func (*Auth_OTP) ProtoMessage

func (*Auth_OTP) ProtoMessage()

func (*Auth_OTP) ProtoReflect

func (x *Auth_OTP) ProtoReflect() protoreflect.Message

func (*Auth_OTP) Reset

func (x *Auth_OTP) Reset()

func (*Auth_OTP) String

func (x *Auth_OTP) String() string

func (*Auth_OTP) UnmarshalJSON

func (msg *Auth_OTP) UnmarshalJSON(b []byte) error

UnmarshalJSON implements json.Unmarshaler

type Auth_Otp

type Auth_Otp struct {
	Otp *Auth_OTP `protobuf:"bytes,1,opt,name=otp,proto3,oneof"`
}

type Auth_Token

type Auth_Token struct {
	RefreshTokenId string `protobuf:"bytes,1,opt,name=refresh_token_id,json=refreshTokenId,proto3" json:"refresh_token_id,omitempty"`
	ExpiresAt      int64  `protobuf:"varint,2,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
	// contains filtered or unexported fields
}

func (*Auth_Token) Descriptor deprecated

func (*Auth_Token) Descriptor() ([]byte, []int)

Deprecated: Use Auth_Token.ProtoReflect.Descriptor instead.

func (*Auth_Token) GetExpiresAt

func (x *Auth_Token) GetExpiresAt() int64

func (*Auth_Token) GetRefreshTokenId

func (x *Auth_Token) GetRefreshTokenId() string

func (*Auth_Token) MarshalJSON

func (msg *Auth_Token) MarshalJSON() ([]byte, error)

MarshalJSON implements json.Marshaler

func (*Auth_Token) ProtoMessage

func (*Auth_Token) ProtoMessage()

func (*Auth_Token) ProtoReflect

func (x *Auth_Token) ProtoReflect() protoreflect.Message

func (*Auth_Token) Reset

func (x *Auth_Token) Reset()

func (*Auth_Token) String

func (x *Auth_Token) String() string

func (*Auth_Token) UnmarshalJSON

func (msg *Auth_Token) UnmarshalJSON(b []byte) error

UnmarshalJSON implements json.Unmarshaler

type Auth_Token_

type Auth_Token_ struct {
	// verified
	Token *Auth_Token `protobuf:"bytes,10,opt,name=token,proto3,oneof"`
}

type Contact

type Contact struct {

	// Types that are valid to be assigned to Via:
	//
	//	*Contact_Guest
	//	*Contact_Email
	//	*Contact_Phone
	//	*Contact_Eip191Address
	Via isContact_Via `protobuf_oneof:"via"`
	// contains filtered or unexported fields
}

func (*Contact) Descriptor deprecated

func (*Contact) Descriptor() ([]byte, []int)

Deprecated: Use Contact.ProtoReflect.Descriptor instead.

func (*Contact) GetEip191Address added in v0.16.9

func (x *Contact) GetEip191Address() string

func (*Contact) GetEmail

func (x *Contact) GetEmail() string

func (*Contact) GetGuest added in v0.19.26

func (x *Contact) GetGuest() int64

func (*Contact) GetPhone

func (x *Contact) GetPhone() string

func (*Contact) GetVia added in v0.19.2

func (x *Contact) GetVia() isContact_Via

func (*Contact) MarshalJSON

func (msg *Contact) MarshalJSON() ([]byte, error)

MarshalJSON implements json.Marshaler

func (*Contact) ProtoMessage

func (*Contact) ProtoMessage()

func (*Contact) ProtoReflect

func (x *Contact) ProtoReflect() protoreflect.Message

func (*Contact) Reset

func (x *Contact) Reset()

func (*Contact) String

func (x *Contact) String() string

func (*Contact) UnmarshalJSON

func (msg *Contact) UnmarshalJSON(b []byte) error

UnmarshalJSON implements json.Unmarshaler

type Contact_Eip191Address added in v0.16.9

type Contact_Eip191Address struct {
	Eip191Address string `protobuf:"bytes,4,opt,name=eip191_address,json=eip191Address,proto3,oneof"`
}

type Contact_Email

type Contact_Email struct {
	Email string `protobuf:"bytes,2,opt,name=email,proto3,oneof"`
}

type Contact_Guest added in v0.19.26

type Contact_Guest struct {
	Guest int64 `protobuf:"varint,1,opt,name=guest,proto3,oneof"`
}

type Contact_Phone

type Contact_Phone struct {
	Phone string `protobuf:"bytes,3,opt,name=phone,proto3,oneof"`
}

type Session

type Session struct {
	Key      string   `protobuf:"bytes,1,opt,name=key,json=_key,proto3" json:"key,omitempty"`
	Id       string   `protobuf:"bytes,2,opt,name=id,json=_id,proto3" json:"id,omitempty"`
	Revision string   `protobuf:"bytes,3,opt,name=revision,json=_rev,proto3" json:"revision,omitempty"`
	Contact  *Contact `protobuf:"bytes,4,opt,name=contact,proto3" json:"contact,omitempty"`
	Auth     *Auth    `protobuf:"bytes,5,opt,name=auth,proto3" json:"auth,omitempty"`
	// contains filtered or unexported fields
}

func (*Session) Descriptor deprecated

func (*Session) Descriptor() ([]byte, []int)

Deprecated: Use Session.ProtoReflect.Descriptor instead.

func (*Session) GetAuth

func (x *Session) GetAuth() *Auth

func (*Session) GetContact

func (x *Session) GetContact() *Contact

func (*Session) GetId

func (x *Session) GetId() string

func (*Session) GetKey

func (x *Session) GetKey() string

func (*Session) GetRevision

func (x *Session) GetRevision() string

func (*Session) MarshalJSON

func (msg *Session) MarshalJSON() ([]byte, error)

MarshalJSON implements json.Marshaler

func (*Session) ProtoMessage

func (*Session) ProtoMessage()

func (*Session) ProtoReflect

func (x *Session) ProtoReflect() protoreflect.Message

func (*Session) Reset

func (x *Session) Reset()

func (*Session) String

func (x *Session) String() string

func (*Session) UnmarshalJSON

func (msg *Session) UnmarshalJSON(b []byte) error

UnmarshalJSON implements json.Unmarshaler

Jump to