Documentation
¶
Index ¶
- Variables
- type Auth
- func (*Auth) Descriptor() ([]byte, []int)deprecated
- func (x *Auth) GetAuth() isAuth_Auth
- func (x *Auth) GetNonce() *Auth_Nonce
- func (x *Auth) GetOtp() *Auth_OTP
- func (x *Auth) GetToken() *Auth_Token
- func (msg *Auth) MarshalJSON() ([]byte, error)
- func (*Auth) ProtoMessage()
- func (x *Auth) ProtoReflect() protoreflect.Message
- func (x *Auth) Reset()
- func (x *Auth) String() string
- func (msg *Auth) UnmarshalJSON(b []byte) error
- type Auth_Nonce
- func (*Auth_Nonce) Descriptor() ([]byte, []int)deprecated
- func (x *Auth_Nonce) GetExpiresAt() int64
- func (x *Auth_Nonce) GetValue() []byte
- func (msg *Auth_Nonce) MarshalJSON() ([]byte, error)
- func (*Auth_Nonce) ProtoMessage()
- func (x *Auth_Nonce) ProtoReflect() protoreflect.Message
- func (x *Auth_Nonce) Reset()
- func (x *Auth_Nonce) String() string
- func (msg *Auth_Nonce) UnmarshalJSON(b []byte) error
- type Auth_Nonce_
- type Auth_OTP
- func (*Auth_OTP) Descriptor() ([]byte, []int)deprecated
- func (x *Auth_OTP) GetAttempts() int32
- func (x *Auth_OTP) GetCode() []byte
- func (x *Auth_OTP) GetExpiresAt() int64
- func (msg *Auth_OTP) MarshalJSON() ([]byte, error)
- func (*Auth_OTP) ProtoMessage()
- func (x *Auth_OTP) ProtoReflect() protoreflect.Message
- func (x *Auth_OTP) Reset()
- func (x *Auth_OTP) String() string
- func (msg *Auth_OTP) UnmarshalJSON(b []byte) error
- type Auth_Otp
- type Auth_Token
- func (*Auth_Token) Descriptor() ([]byte, []int)deprecated
- func (x *Auth_Token) GetExpiresAt() int64
- func (x *Auth_Token) GetRefreshTokenId() string
- func (msg *Auth_Token) MarshalJSON() ([]byte, error)
- func (*Auth_Token) ProtoMessage()
- func (x *Auth_Token) ProtoReflect() protoreflect.Message
- func (x *Auth_Token) Reset()
- func (x *Auth_Token) String() string
- func (msg *Auth_Token) UnmarshalJSON(b []byte) error
- type Auth_Token_
- type Contact
- func (*Contact) Descriptor() ([]byte, []int)deprecated
- func (x *Contact) GetEip191Address() string
- func (x *Contact) GetEmail() string
- func (x *Contact) GetGuest() int64
- func (x *Contact) GetPhone() string
- func (x *Contact) GetVia() isContact_Via
- func (msg *Contact) MarshalJSON() ([]byte, error)
- func (*Contact) ProtoMessage()
- func (x *Contact) ProtoReflect() protoreflect.Message
- func (x *Contact) Reset()
- func (x *Contact) String() string
- func (msg *Contact) UnmarshalJSON(b []byte) error
- type Contact_Eip191Address
- type Contact_Email
- type Contact_Guest
- type Contact_Phone
- type Session
- func (*Session) Descriptor() ([]byte, []int)deprecated
- func (x *Session) GetAuth() *Auth
- func (x *Session) GetContact() *Contact
- func (x *Session) GetId() string
- func (x *Session) GetKey() string
- func (x *Session) GetRevision() string
- func (msg *Session) MarshalJSON() ([]byte, error)
- func (*Session) ProtoMessage()
- func (x *Session) ProtoReflect() protoreflect.Message
- func (x *Session) Reset()
- func (x *Session) String() string
- func (msg *Session) UnmarshalJSON(b []byte) error
Constants ¶
This section is empty.
Variables ¶
var File_gx_auth_v1_session_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Auth ¶
type Auth struct {
// Types that are valid to be assigned to Auth:
//
// *Auth_Otp
// *Auth_Nonce_
// *Auth_Token_
Auth isAuth_Auth `protobuf_oneof:"auth"`
// contains filtered or unexported fields
}
func (*Auth) Descriptor
deprecated
func (*Auth) GetNonce ¶ added in v0.15.0
func (x *Auth) GetNonce() *Auth_Nonce
func (*Auth) GetToken ¶
func (x *Auth) GetToken() *Auth_Token
func (*Auth) MarshalJSON ¶
MarshalJSON implements json.Marshaler
func (*Auth) ProtoMessage ¶
func (*Auth) ProtoMessage()
func (*Auth) ProtoReflect ¶
func (x *Auth) ProtoReflect() protoreflect.Message
func (*Auth) UnmarshalJSON ¶
UnmarshalJSON implements json.Unmarshaler
type Auth_Nonce ¶ added in v0.15.0
type Auth_Nonce struct {
Value []byte `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
ExpiresAt int64 `protobuf:"varint,2,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
// contains filtered or unexported fields
}
func (*Auth_Nonce) Descriptor
deprecated
added in
v0.15.0
func (*Auth_Nonce) Descriptor() ([]byte, []int)
Deprecated: Use Auth_Nonce.ProtoReflect.Descriptor instead.
func (*Auth_Nonce) GetExpiresAt ¶ added in v0.15.0
func (x *Auth_Nonce) GetExpiresAt() int64
func (*Auth_Nonce) GetValue ¶ added in v0.17.0
func (x *Auth_Nonce) GetValue() []byte
func (*Auth_Nonce) MarshalJSON ¶ added in v0.15.0
func (msg *Auth_Nonce) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler
func (*Auth_Nonce) ProtoMessage ¶ added in v0.15.0
func (*Auth_Nonce) ProtoMessage()
func (*Auth_Nonce) ProtoReflect ¶ added in v0.15.0
func (x *Auth_Nonce) ProtoReflect() protoreflect.Message
func (*Auth_Nonce) Reset ¶ added in v0.15.0
func (x *Auth_Nonce) Reset()
func (*Auth_Nonce) String ¶ added in v0.15.0
func (x *Auth_Nonce) String() string
func (*Auth_Nonce) UnmarshalJSON ¶ added in v0.15.0
func (msg *Auth_Nonce) UnmarshalJSON(b []byte) error
UnmarshalJSON implements json.Unmarshaler
type Auth_Nonce_ ¶ added in v0.15.0
type Auth_Nonce_ struct {
Nonce *Auth_Nonce `protobuf:"bytes,2,opt,name=nonce,proto3,oneof"`
}
type Auth_OTP ¶
type Auth_OTP struct {
Code []byte `protobuf:"bytes,1,opt,name=code,proto3" json:"code,omitempty"`
ExpiresAt int64 `protobuf:"varint,2,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
Attempts int32 `protobuf:"varint,3,opt,name=attempts,proto3" json:"attempts,omitempty"`
// contains filtered or unexported fields
}
func (*Auth_OTP) Descriptor
deprecated
func (*Auth_OTP) GetAttempts ¶ added in v0.17.0
func (*Auth_OTP) GetExpiresAt ¶
func (*Auth_OTP) MarshalJSON ¶
MarshalJSON implements json.Marshaler
func (*Auth_OTP) ProtoMessage ¶
func (*Auth_OTP) ProtoMessage()
func (*Auth_OTP) ProtoReflect ¶
func (x *Auth_OTP) ProtoReflect() protoreflect.Message
func (*Auth_OTP) UnmarshalJSON ¶
UnmarshalJSON implements json.Unmarshaler
type Auth_Otp ¶
type Auth_Otp struct {
Otp *Auth_OTP `protobuf:"bytes,1,opt,name=otp,proto3,oneof"`
}
type Auth_Token ¶
type Auth_Token struct {
RefreshTokenId string `protobuf:"bytes,1,opt,name=refresh_token_id,json=refreshTokenId,proto3" json:"refresh_token_id,omitempty"`
ExpiresAt int64 `protobuf:"varint,2,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
// contains filtered or unexported fields
}
func (*Auth_Token) Descriptor
deprecated
func (*Auth_Token) Descriptor() ([]byte, []int)
Deprecated: Use Auth_Token.ProtoReflect.Descriptor instead.
func (*Auth_Token) GetExpiresAt ¶
func (x *Auth_Token) GetExpiresAt() int64
func (*Auth_Token) GetRefreshTokenId ¶
func (x *Auth_Token) GetRefreshTokenId() string
func (*Auth_Token) MarshalJSON ¶
func (msg *Auth_Token) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler
func (*Auth_Token) ProtoMessage ¶
func (*Auth_Token) ProtoMessage()
func (*Auth_Token) ProtoReflect ¶
func (x *Auth_Token) ProtoReflect() protoreflect.Message
func (*Auth_Token) Reset ¶
func (x *Auth_Token) Reset()
func (*Auth_Token) String ¶
func (x *Auth_Token) String() string
func (*Auth_Token) UnmarshalJSON ¶
func (msg *Auth_Token) UnmarshalJSON(b []byte) error
UnmarshalJSON implements json.Unmarshaler
type Auth_Token_ ¶
type Auth_Token_ struct {
// verified
Token *Auth_Token `protobuf:"bytes,10,opt,name=token,proto3,oneof"`
}
type Contact ¶
type Contact struct {
// Types that are valid to be assigned to Via:
//
// *Contact_Guest
// *Contact_Email
// *Contact_Phone
// *Contact_Eip191Address
Via isContact_Via `protobuf_oneof:"via"`
// contains filtered or unexported fields
}
func (*Contact) Descriptor
deprecated
func (*Contact) GetEip191Address ¶ added in v0.16.9
func (*Contact) MarshalJSON ¶
MarshalJSON implements json.Marshaler
func (*Contact) ProtoMessage ¶
func (*Contact) ProtoMessage()
func (*Contact) ProtoReflect ¶
func (x *Contact) ProtoReflect() protoreflect.Message
func (*Contact) UnmarshalJSON ¶
UnmarshalJSON implements json.Unmarshaler
type Contact_Eip191Address ¶ added in v0.16.9
type Contact_Eip191Address struct {
Eip191Address string `protobuf:"bytes,4,opt,name=eip191_address,json=eip191Address,proto3,oneof"`
}
type Contact_Email ¶
type Contact_Email struct {
Email string `protobuf:"bytes,2,opt,name=email,proto3,oneof"`
}
type Contact_Guest ¶ added in v0.19.26
type Contact_Guest struct {
Guest int64 `protobuf:"varint,1,opt,name=guest,proto3,oneof"`
}
type Contact_Phone ¶
type Contact_Phone struct {
Phone string `protobuf:"bytes,3,opt,name=phone,proto3,oneof"`
}
type Session ¶
type Session struct {
Key string `protobuf:"bytes,1,opt,name=key,json=_key,proto3" json:"key,omitempty"`
Id string `protobuf:"bytes,2,opt,name=id,json=_id,proto3" json:"id,omitempty"`
Revision string `protobuf:"bytes,3,opt,name=revision,json=_rev,proto3" json:"revision,omitempty"`
Contact *Contact `protobuf:"bytes,4,opt,name=contact,proto3" json:"contact,omitempty"`
Auth *Auth `protobuf:"bytes,5,opt,name=auth,proto3" json:"auth,omitempty"`
// contains filtered or unexported fields
}
func (*Session) Descriptor
deprecated
func (*Session) GetContact ¶
func (*Session) GetRevision ¶
func (*Session) MarshalJSON ¶
MarshalJSON implements json.Marshaler
func (*Session) ProtoMessage ¶
func (*Session) ProtoMessage()
func (*Session) ProtoReflect ¶
func (x *Session) ProtoReflect() protoreflect.Message
func (*Session) UnmarshalJSON ¶
UnmarshalJSON implements json.Unmarshaler
Click to show internal directories.
Click to hide internal directories.